==> webknossos-0.12.2.tar.gz: webknossos-0.12.2/webknossos/client/_generated/models/dataset_sharing_token_response_200.py <==
from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="DatasetSharingTokenResponse200")


@attr.s(auto_attribs=True)
class DatasetSharingTokenResponse200:
    """
    Attributes:
        sharing_token (str):  Example: Vui0y7qCWj66ylpMhEzdJg.
    """

    sharing_token: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        sharing_token = self.sharing_token

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "sharingToken": sharing_token,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        sharing_token = d.pop("sharingToken")

        dataset_sharing_token_response_200 = cls(
            sharing_token=sharing_token,
        )

        dataset_sharing_token_response_200.additional_properties = d
        return dataset_sharing_token_response_200

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> webknossos-0.13.0.tar.gz: webknossos-0.13.0/webknossos/client/_generated/models/dataset_sharing_token_response_200.py <==
from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="DatasetSharingTokenResponse200")


@attr.s(auto_attribs=True)
class DatasetSharingTokenResponse200:
    """
    Attributes:
        sharing_token (str):
    """

    sharing_token: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        sharing_token = self.sharing_token

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "sharingToken": sharing_token,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        sharing_token = d.pop("sharingToken")

        dataset_sharing_token_response_200 = cls(
            sharing_token=sharing_token,
        )

        dataset_sharing_token_response_200.additional_properties = d
        return dataset_sharing_token_response_200

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
